getMatchStatus property
Optional callback to retrieve the status of a match
Implementation
final MatchStatus Function(T match)? getMatchStatus;
Optional callback to retrieve the status of a match
final MatchStatus Function(T match)? getMatchStatus;