tabBuilder property
Custom Tab item builder. Allows developers to fully customize the round tab labels!
Implementation
final Widget Function(BuildContext context, int index, bool isSelected)?
tabBuilder;
Custom Tab item builder. Allows developers to fully customize the round tab labels!
final Widget Function(BuildContext context, int index, bool isSelected)?
tabBuilder;