useLineGradients property
Whether to draw gradient connection lines from source to destination matches.
Implementation
final bool useLineGradients;
Whether to draw gradient connection lines from source to destination matches.
final bool useLineGradients;