BracketPainter<T> class

A high-performance CustomPainter that draws orthogonal victory-glow connecting lines between match cards of generic type T, dynamically morphing their coordinates in real time.

Inheritance

Constructors

BracketPainter({required double cardWidth, required double cardHeight, required double horizontalGap, required double verticalGap, required double topOffset, required List<List<T>> branchRounds, required T? finalMatch, T? thirdPlaceMatch, required double pageOffset, required Color primaryColor, required Color secondaryColor, required Color accentColor, required Color defaultLineColor, required double connectorRadius, required double lineThickness, required double activeLineThickness, required double activeGlowWidth, required double activeGlowOpacity, required ConnectorStyle connectorStyle, required ConnectorLineType lineType, required double dashLength, required double dashGap, required double dashSpeedMultiplier, String? searchHighlightQuery, required double pulseValue, required double flowValue, required bool useLineGradients, bool hasWinner(T match)?, String getWinnerName(T match)?, String getPlayer1Name(T match)?, String getPlayer2Name(T match)?, MatchStatus getMatchStatus(T match)?, required Color disputeColor})

Properties

accentColor Color
final
activeGlowOpacity double
final
activeGlowWidth double
final
activeLineThickness double
final
branchRounds List<List<T>>
final
cardHeight double
final
cardWidth double
final
connectorRadius double
final
connectorStyle ConnectorStyle
final
dashGap double
final
dashLength double
final
dashSpeedMultiplier double
final
defaultLineColor Color
final
disputeColor Color
final
finalMatch → T?
final
flowValue double
final
getMatchStatus MatchStatus Function(T match)?
final
getPlayer1Name String Function(T match)?
final
getPlayer2Name String Function(T match)?
final
getWinnerName String Function(T match)?
final
hashCode int
The hash code for this object.
no setterinherited
hasWinner bool Function(T match)?
final
horizontalGap double
final
lineThickness double
final
lineType ConnectorLineType
final
pageOffset double
final
primaryColor Color
final
pulseValue double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHighlightQuery String?
final
secondaryColor Color
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
thirdPlaceMatch → T?
final
topOffset double
final
useLineGradients bool
final
verticalGap double
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
getActiveY(int round, int index) double
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant BracketPainter<T> oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited