Player class

Convenience model representing a player in a tournament (can be used as a default).

Constructors

Player({required String name, required String flag, bool isWalkOver = false, bool isCheckedIn = false})
const

Properties

flag String
final
hashCode int
The hash code for this object.
no setterinherited
isCheckedIn bool
final
isWalkOver bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

walkOver → const Player