animated_tournament_bracket
library
Classes
-
AnimatedTournamentBracket<T>
-
A premium, highly customizable generic tournament bracket widget supporting any match model T.
-
BracketPainter<T>
-
A high-performance CustomPainter that draws orthogonal victory-glow connecting lines
between match cards of generic type T, dynamically morphing their coordinates in real time.
-
MatchModel<P>
-
Convenience model representing a match in a tournament (can be used as a default).
-
Player
-
Convenience model representing a player in a tournament (can be used as a default).
Enums
-
BracketViewMode
-
A premium, highly customizable generic tournament bracket widget supporting any match model /// View mode for the bracket: Carousel Swipe or 2D Interactive Zoom/Pan
-
ConnectorLineType
-
-
ConnectorStyle
-
Style of connection lines between rounds
-
MatchStatus
-
Enum representing the execution status of a match based on the tournament workflow.