MatchModel<P> class
Convenience model representing a match in a tournament (can be used as a default).
Constructors
-
MatchModel({required int id, required String label, required String table, required String time, required List<
P> competitors, required List<int> scores, MatchStatus status = MatchStatus.scheduled}) -
const
Properties
-
competitors
→ List<
P> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWinner → bool
-
no setter
- id → int
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scores
→ List<
int> -
final
- status → MatchStatus
-
final
- table → String
-
final
- time → String
-
final
- winner → P?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited